#!/usr/bin/env python

from distutils.core import setup
from distutils.command.install import install
import glob
import sys
from picard import APPNAME, APPVERSION

args = {}

def generate_file(infilename, outfilename, variables):
    f = file(infilename, "rt")
    content = f.read()
    f.close()
    content = content % variables
    f = file(outfilename, "wt")
    f.write(content)
    f.close()

class my_install(install):
    def run(self):
        generate_file('scripts/picard.in', 'scripts/picard', {'localedir': '%s/share/locale' % (self.install_data,)})
        install.run(self)
args['cmdclass'] = {'install': my_install}

try:
    from py2exe.build_exe import py2exe
except:
    py2exe = None
else:
    class bdist_nsis(py2exe):
        def run(self):
            self.distribution.data_files = [(a.replace('share/locale', 'locale'), b) for (a,b) in self.distribution.data_files]
            generate_file('scripts/picard.py2exe.in', 'scripts/picard', {})
            self.distribution.data_files.append(("", glob.glob("*.dll")))
            self.distribution.data_files.append(("plugins", glob.glob("plugins/*.tpp")))
            
            py2exe.run(self)
            
            print "*** creating the NSIS setup script ***"
            pathname = "installer/picard-setup.nsi"
            generate_file(pathname + ".in", pathname, {'name': APPNAME, 'version': APPVERSION})
        
            print "*** compiling the NSIS setup script ***"
            import ctypes
            res = ctypes.windll.shell32.ShellExecuteA(0, "compile", pathname, None, None, 0)
            if res < 32:
                raise RuntimeError, "ShellExecute failed, error %d" % (res,)
    args['cmdclass']['bdist_nsis'] = bdist_nsis
    
    manifest = '''
<?xml version="1.0" encoding="UTF-8" standalone="yes"?>
<assembly xmlns="urn:schemas-microsoft-com:asm.v1" manifestVersion="1.0">
<assemblyIdentity
    version="0.0.0.0"
    processorArchitecture="x86"
    name="%(name)s"
    type="win32"
/>
<description>%(name)s</description>
<dependency>
    <dependentAssembly>
        <assemblyIdentity
            type="win32"
            name="Microsoft.Windows.Common-Controls"
            version="6.0.0.0"
            processorArchitecture="X86"
            publicKeyToken="6595b64144ccf1df"
            language="*"
        />
    </dependentAssembly>
</dependency>
</assembly>
''' % dict(name=APPNAME)
    
    args['windows'] = {
        'script': 'scripts/picard',
        'icon_resources': [(1, 'rc/picard.ico')],
        'other_resources': [(24, 1, manifest)]
        },
        
    args['options'] = {
        'py2exe': {'packages': ['encodings'], 'optimize': 2}, 
        'win32fil': {'packages': ['win32api']},
        'win32api': {'packages': ['win32api']},
        'win32con': {'packages': ['win32api']}
        }
        
data_files = [('share/%s/LC_MESSAGES' % (locale,),
              ['%s/LC_MESSAGES/picard.mo' % (locale,)]) for locale in glob.glob('locale/*')]

if py2exe == None:
    data_files.append(('share/icons', ('rc/picard16.png', 'rc/picard32.png')))
    data_files.append(('share/applications', ('picard.desktop',)))

setup(
    name='picard',
    version=APPVERSION,
    description="The next generation MusicBrainz tagger",
    url="http://wiki.musicbrainz.org/PicardTagger",
    package_dir={'picard': 'picard'},
    packages=['picard', 'picard.ui', 'picard.ui.options', 'picard.browser'],
    scripts=['scripts/picard'],
    data_files=data_files,
    **args
    )

